export default function ({sendRequest, setData, platform, route}) {
    return class Feeds {
        constructor({props}) {
            this.seq = 1;
            this.items = [];
            this.activityID = route.queryParams.activityID || ''
            this.source = route.queryParams.source || '38'
            console.log('bargain-list route: ' + JSON.stringify(route.queryParams));
        }

        onReachBottom() {
            this.loadMore();
        }

        onLoad() {
            this.fetchData();
        }

        onRefresh() {
            this.seq = 1;
            this.items = [];
            setData({
                showLoading: false
            })
            this.onLoad();
        }

        loadMore() {
            this.seq += 1;
            setData({
                showLoading: true
            });
            this.fetchData();
        }

        fetchData() {
            sendRequest({
                path: 'recommend/feedsqueryitem',
                data: {
                    Seq: this.seq,
                    Source: this.source,
                    RequestOption: {
                        Category2: '0',
                        limit: '10',
                        channelID: '1',
                        activityID: this.activityID
                    }
                },
                success: (res) => {
                    let processedRes = this.processResponse(res.body);
                    this.items = this.items.concat(processedRes);
                    console.log('processed items length ' + this.items.length);
                    setData({
                        items: this.items
                    });
                },
                fail: (err) => {
                    console.log('request feeds failed', err);
                }
            });
        }

        processResponse(resp) {
            let items = [];
            if (resp.ItemList) {
                resp.ItemList.forEach(product => {
                        const {
                            ImgUrl = [],
                            Title,
                            ResponseOption: {opActivityMinPrice = 0, opTags} = {},
                            MinPrice = 0,
                            MaxPrice = 0
                        } = product.SpuInfo;
                        let bargainPrice;
                        let originPrice = product.SpuInfo.marketPrice || product.SpuInfo.MarketPrice || product.SpuInfo.MaxPrice;
                        if (MinPrice < opActivityMinPrice) {
                            bargainPrice = Math.abs((MaxPrice - opActivityMinPrice) / 100);
                        } else {
                            bargainPrice = Math.abs((MinPrice - opActivityMinPrice) / 100);
                        }

                        let activityPrice = opActivityMinPrice || originPrice;
                        let tags = opTags ? JSON.parse(opTags) : {};
                        const person = tags['19'] ? '?' : this.getBargainCount(bargainPrice);

                        let afterTags = this.getTitleAfterTags(tags);
                        let beforeTags = this.getTitleBeforeTags(tags);
                        let item = {
                            spuId: Number(product.SpuInfo.SpuID),
                            shopId:Number(product.SpuInfo.ShopID),
                            title: Tags.getTagsPlaceHolder(beforeTags) + Title,
                            beforeTagsSpan: beforeTags,
                            afterTagsVisible: afterTags.length > 0,
                            afterTags: Tags.getTagsPlaceHolder(afterTags),
                            afterTagsSpan: afterTags,
                            image: ImgUrl[0] + '?imageMogr2/thumbnail/!480x480r',
                            originPrice: CommonBusinessScripts.formatPrice(originPrice),
                            activityPrice: parseInt(activityPrice / 100),
                            activityPriceDecimal: CommonBusinessScripts.getPriceDecimal(activityPrice),
                            person
                        };
                        items.push(item);
                    }
                );
            }
            return items
        }

        onActivityRuleClick() {
            callNative("bargain_list", "onActivityRuleClick", null, null)
        }

        getBargainCount(bargainPrice) {
            const BARGAIN_RANGE = [
                {MAX: 2, COUNT: 2},
                {MAX: 10, COUNT: 3},
                {MAX: 16, COUNT: 4},
                {MAX: 60, COUNT: 5},
                {MAX: 80, COUNT: 10},
                {MAX: 150, COUNT: 15},
                {MAX: Number.MAX_SAFE_INTEGER, COUNT: 20},
            ];

            for (let i = 0, len = BARGAIN_RANGE.length; i < len; i++) {
                if (bargainPrice <= BARGAIN_RANGE[i].MAX) {
                    return BARGAIN_RANGE[i].COUNT;
                }
            }
        }

        getTitleAfterTags(tags) {
            const showTags = [TAGS.COUPON, TAGS.ALLOWANCE, TAGS.BAD_FRUIT, TAGS.FREE_RETURN, TAGS.PAY_ONE_FAKE, TAGS.LABEL_8];
            return Tags.getTags(tags, showTags);
        }

        getTitleBeforeTags(tags) {
            const showTags = [TAGS.LABEL_30, TAGS.PRE_SALE, TAGS.LABEL_12, TAGS.BRAND];
            return Tags.getTags(tags, showTags);
        }
    }
}