export default function ({ sendRequest, setData, platform }) {
  function serverFactory(path) {
    return (payLoad) => {
      const { params = {} } = payLoad || {};

      return new Promise((resolve, reject) => {
        sendRequest({
          path,
          data: params,
          success: (res) => {
            if (res && res.body) {
              return resolve(res.body);
            }
            return reject(new Error('empty data'));
          },
          fail: (err) => {
            console.error(`>>> request error: ${path} >`, err);
            reject(err);
          },
        });
      });
    };
  }
  const FarmServer = {
    DefaultInfo: {
      title: '庄园0元换',
      tag: '0元',
      desc: '0元免费领',
      status: 0,
      btn: '去种植',
    },
    FarmEvent: {
      Nothing: 0,
      CropGrownRice: 17, // 水稻成熟
      CropGrownPotato: 18, // 土豆成熟
      CropGrownMongo: 19, // 芒果成熟
      CoinTaskFinished: 22, // 金币待领取
      FertilizerTaskFinished: 23, // 肥料待领取
    },
    getEventInfo(activityType) {
      switch (activityType) {
        case FarmServer.FarmEvent.CropGrownRice:
          return {
            tag: '丰收',
            desc: '种果蔬得实物',
            image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/rice.png',
            status: activityType,
            btn: '去收获',
          };
        case FarmServer.FarmEvent.CropGrownPotato:
          return {
            tag: '丰收',
            desc: '种果蔬得实物',
            image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/potato.png',
            status: activityType,
            btn: '去收获',
          };
        case FarmServer.FarmEvent.CropGrownMongo:
          return {
            tag: '丰收',
            desc: '种果蔬得实物',
            image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/mango.png',
            status: activityType,
            btn: '去收获',
          };
        case FarmServer.FarmEvent.CoinTaskFinished:
          return {
            tag: '金币',
            desc: '每日免费领金币',
            image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/coin.png',
            status: activityType,
            btn: '去领取',
          };
        case FarmServer.FarmEvent.FertilizerTaskFinished: {
          return {
            tag: '施肥',
            desc: '领肥料促生长',
            image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/fertilizer.png',
            status: activityType,
            btn: '去领取',
          };
        }
        default:
          FarmServer.DefaultInfo.btn = '立即领';
          FarmServer.DefaultInfo.desc = '0元免费领';
          FarmServer.DefaultInfo.image = 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/coin.png';
          return FarmServer.DefaultInfo;
      }
    },
    getFarmEvent: serverFactory('farm/getuserrecommendgroupshop'),
    async getFarmInfo() {
      /*
      const { LatestFarmActionEvent: {
        FarmActionType = 0,
      } = {} } = await FarmServer.getFarmEvent();
      */
      // 更新默认信息
      return FarmServer.DefaultInfo = FarmServer.getEventInfo(0);
    },
  };
  const TreasureServer = {
    DefaultInfo: { title: '小鹅寻宝', desc: '送红包赢5折', image: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/treasure-iphone.png' },
    getLotterynum: serverFactory('deplay/lotterynum'),
    getPlayerInfo: serverFactory('deplay/playerinfo'),
    getPrizeList: serverFactory('deactinfo/prizelist').bind(null, { params: { ThemeId: '10087', Limit: 0 } }),
    getTaskList: serverFactory('detask/gettasklist').bind(null, { params: { ModulePrefix: 'yz_ug_1111' } }),
    async getStatusText() {
      const { TotalPlayTimes, LotteryNum } = await TreasureServer.getPlayerInfo();
      if (LotteryNum) {
        return `${LotteryNum}次机会待使用`;
      }
      if (!TotalPlayTimes) {
        return '送红包赢5折';
      }
      let { Items = [] } = await TreasureServer.getPrizeList();
      // 过滤未使用的五折卡
      Items = Items.filter(item => item.HalfOffVoucherPrize && item.HalfOffVoucherPrize.Status === 1);
      if (Items.length) {
        // 暂时不显示
        return `${Items.length}张5折卡待使用`;
      }
      const { List = [] } = await TreasureServer.getTaskList();
      // 待领取机会
      const willTimes = List.reduce((pre, cur) => {
        const { Task: {
          MaxNum = 0,
          CurNum = 0,
        } = {},
          Frame: {
            AwardChance = 0,
          } = {},
        } = cur;
        // 有奖励次数才计算
        return pre + (AwardChance && (MaxNum - CurNum));
      }, 0);
      if (willTimes) {
        return `${willTimes}次机会待领取`;
      }
      return '送红包赢5折';
    },
  };

  return class HomeActivityEntry {
    constructor({ props }) {
      this.config = [];
      this.farmInfo = FarmServer.DefaultInfo;
      this.treasureInfo = TreasureServer.DefaultInfo;
      if (props && props.value) {
        this.config = JSON.parse(props.value);
        if (this.config.activity && this.config.activity.length) {
          this.treasureInfo = this.config.activity.find((item) => item.id == 'treasure');
          this.farmInfo = this.config.activity.find((item) => item.id == 'farm');
        }
      }
    }

    onLoad() {
      setData({
        farmInfo: this.farmInfo,
        treasureInfo: this.treasureInfo,
      });
      this.getFarmInfo();
      this.getTreasureInfo();
    }

    getTreasureInfo() {
      TreasureServer.getStatusText()
        .then((res) => {
          this.treasureInfo.desc = res;
          setData({
            treasureInfo: this.treasureInfo
          });
        })
        .catch((err) => {
          console.log(err);
        });
    }

    getFarmInfo() {
      FarmServer.getFarmInfo()
        .then((res) => {
          this.farmInfo.title = res.title;
          this.farmInfo.desc = res.desc;
          this.farmInfo.image = res.image;
          setData({
            farmInfo: this.farmInfo
          });
        })
        .catch((err) => {
          console.error(err);
        });
    }
  };
}
