function formatPrice(priceCent) {
  if (priceCent % 100 == 0) {
    return (priceCent / 100).toFixed(0);
  } else if (priceCent % 10 == 0) {
    return (priceCent / 100).toFixed(1);
  }
  return (priceCent / 100).toFixed(2);
}

export default function ({ sendRequest, setData, platform }) {
  return class HomeAllowance {
    constructor({ props, style }) {
      this.productItems = [];
      this.seq = 0;
      this.config = {};
      if (props && props.value) {
        this.config = JSON.parse(props.value);
        this.config.noAvatar = !this.config.showAvatar;
        if (this.config.showAvatar) {
          this.config.backgroundColor = '#ffffff';
        } else {
          this.config.backgroundColor = 'linear-gradient(92deg, #ED2F49 50%, #ED687A 99%)';
        }
        this.config.newUserType0 = this.config.numberOfOrder == 0;
        this.config.notNewUserType0 = this.config.numberOfOrder != 0;
      }
    }

    onLoad() {
      setData({
        config: this.config,
      });
      this.fetchProducts();
      if (this.config.showAvatar) {
        this.fetchAvatars();
      }
    }

    fetchAvatars() {
      sendRequest({
        path: 'deactinfo/pagejoinusers',
        data: {
          Offset: parseInt(Math.random() * 1900, 10),
          Limit: 3,
        },
        success: (resp) => {
          const res = resp.body;
          this.config.avatars = (res.UserList || []).map(user => user.IconUrl);
          setData({
            config: this.config
          });
        },
        fail: (err) => {
          console.error(err);
        }
      });
    }

    fetchProducts() {
      const { requestOptions } = this.config;
      const { source, topSpuIDList = [], realCate = [], ...restOptions } = requestOptions;
      const fixedRequestOptions = {
        ...restOptions,
        topSpuIDList: topSpuIDList.join('|'),
        realCate: realCate.join('|'),
        channelID: '1',
      };
      sendRequest({
        path: 'recommend/feedsqueryitem',
        data: {
          Source: source || '37',
          RequestOption: fixedRequestOptions,
          Seq: this.seq += 1,
        },
        success: (resp) => {
          const res = resp.body;
          if (res.ItemList && res.ItemList.length !== 0) {
            const itemList = this.productItems.concat(res.ItemList.map((item) => {
              const newItem = {
                ...item,
              };
              if (item.SpuInfo) {
                newItem.showPrice = Math.min(
                  item.SpuInfo.ResponseOption.opActivityMinPrice || Number.MAX_SAFE_INTEGER,
                  item.SpuInfo.MinPrice,
                  (this.config.CouponUsedPrice
                    && item.SpuInfo.WaistInfo
                    && item.SpuInfo.WaistInfo.CouponUsedPrice) || Number.MAX_SAFE_INTEGER,
                  (this.config.EstimatedPrice
                    && item.SpuInfo.WaistInfo
                    && item.SpuInfo.WaistInfo.EstimatedPrice) || Number.MAX_SAFE_INTEGER,
                );
                newItem.showPrice = (newItem.showPrice / 100).toFixed(2);
                [newItem.showImage = ''] = item.SpuInfo.ImgUrl;
                // 处理价格
                const priceRest = (item.SpuInfo.MarketPrice / 100) - newItem.showPrice;
                newItem.showAllowanceRest = `已补${formatPrice(priceRest, 2)}元`;
                newItem.spuId = item.SpuInfo.SpuID;
                newItem.price = newItem.showPrice;
                if (item.SpuInfo.ImgUrl && item.SpuInfo.ImgUrl.length) {
                  newItem.imageUrl = item.SpuInfo.ImgUrl[0];
                }
                let topSpuId = item.SpuInfo.SpuID;
                if (item.SpuInfo.ResponseOption && item.SpuInfo.ResponseOption.activityID) {
                  topSpuId = `${item.SpuInfo.SpuID}-${item.SpuInfo.ResponseOption.activityID}`;
                }
                if (this.config.route.indexOf('?') >= 0) {
                  newItem.route = `${this.config.route}&topSpuId=${topSpuId}`;
                } else {
                  newItem.route = `${this.config.route}?topSpuId=${topSpuId}`;
                }
              }
              return newItem;
            }));
            setData({ items: itemList });
          }
        },
        fail: (err) => {
          console.error(err);
        },
      });
    }
  };
}
