export default function ({ sendRequest, setData, platform }) {
  return class Feeds {
    constructor({ props }) {
      this.seq = 0;
      this.items = [];
    }

    onLoad() {
      this.fetchData();
    }

    onRefresh() {
      this.seq = 0;
      this.items = [];
      setData({
        showLoading: false
      })
      this.onLoad();
    }

    onReachBottom() {
      this.loadMore();
    }

    loadMore() {
      this.seq += 1;
      setData({
        showLoading: true
      });
      this.fetchData();
    }

    fetchData() {
      sendRequest({
        path: 'recommend/feedspersoncenter',
        data: {
          Seq: this.seq,
          Limit: 8,
          Source: '2'
        },
        success: (res) => {
          let processedRes = this.processResponse(res.body);
          this.items = this.items.concat(processedRes);
          console.log('processed items length ' + this.items.length);
          setData({
            items: this.items
          });
        },
        fail: (err) => {
          console.log('request feeds failed', err);
        }
      });
    }

    processResponse(resp) {
      let items = [];
      if (resp.ItemList) {
        resp.ItemList.forEach(item => {
          let spu = item.SpuInfo;
          if (spu) {
            var titlePrefixLabels = '';
            var labels = [];
            var showEasyBuy = false;
            var showFruitGuarantee = false;
            var showCoupon = false;
            var showAllowance = false;
            var coupon = 0;
            var allowance = 0;
            var showWaistInfo = false;
            if (spu.hasOwnProperty('Tags')) {
              if (spu.Tags.hasOwnProperty('3')) {
                showEasyBuy = true;
                showWaistInfo = true;
              }
              if (spu.Tags.hasOwnProperty('20')) {
                showFruitGuarantee = true;
                showWaistInfo = true;
              }
              if (spu.Tags.hasOwnProperty('4')) {
                titlePrefixLabels += '[nb-span]';
                labels.push('[label("品牌"), textSize(22), textColor(0xFFFFFF), backgroundColor(0x000000), radius(4), paddingTop(2), marginRight(4)]');
              }
              if (spu.Tags.hasOwnProperty('5')) {
                titlePrefixLabels += '[nb-span]';
                labels.push('[label("全网低价"), textSize(22), textColor(0xFFFFFF), backgroundColor(0xED2F49), radius(4), paddingTop(2), marginRight(4)]');
              }
            }
            // if (spu.hasOwnProperty('WaistInfo')) {
            //     if (spu.WaistInfo.hasOwnProperty('Coupon') && spu.WaistInfo.Coupon.hasOwnProperty('Name')) {
            //         showCoupon = true;
            //         coupon = spu.WaistInfo.Coupon.Name;
            //         showWaistInfo = true;
            //     }
            //     if (spu.WaistInfo.hasOwnProperty('Allowance') && spu.WaistInfo.Allowance.hasOwnProperty('Name')) {
            //         showAllowance = true;
            //         allowance = spu.WaistInfo.Allowance.Name;
            //         showWaistInfo = true;
            //     }
            // }
            var title = spu.Title;
            var labelStyles = '';
            if (titlePrefixLabels.length > 0) {
              // title = titlePrefixLabels + title;
              labelStyles = '[';
              labels.forEach((label, index) => {
                labelStyles += label;
                if (index < labels.length) {
                  labelStyles += ',';
                }
              });
              labelStyles += ']';
            }
            let showSpuDesc = spu.hasOwnProperty('SpuDescription');
            let item = {
              id: spu.SpuID,
              title,
              labelStyles,
              image: CommonBusinessScripts.spuImage(spu),
              minPrice: CommonBusinessScripts.formatPrice(spu.MinPrice),
              price: CommonBusinessScripts.formatPrice(spu.MinPrice),
              marketPrice: CommonBusinessScripts.formatPrice(spu.MarketPrice),
              shopId: spu.ShopID,
              showSpuDesc,
              showEasyBuy,
              showCoupon,
              showAllowance,
              coupon,
              allowance,
              showWaistInfo,
              showFruitGuarantee,
              spuDesc: spu.SpuDescription
            };
            if (item.hasOwnProperty('ItemHeadInfo') && item.ItemHeadInfo.hasOwnProperty('Logo')) {
              item['spuLogo'] = item.ItemHeadInfo.Logo;
            }
            items.push(item);
          }
        });
      }
      return items;
    }
  }
}