export default function ({ sendRequest, setData, platform, route }) {
  return class Feeds {
    constructor({ props }) {
      const { spuId, shopId } = route.queryParams;
      this.spuId = Number(spuId)
      this.shopId = Number(shopId);

      this.seq = 1;
      this.items = [];
    }

    onLoad() {
      this.fetchDetailsData();
      this.fetchData();
    }

    onRefresh() {
      this.seq = 0;
      this.items = [];
      setData({
        showLoading: false
      })
      this.onLoad();
    }

    onReachBottom() {
      this.loadMore();
    }

    loadMore() {
      this.seq += 1;
      setData({
        showLoading: true
      });
      this.fetchData();
    }

    fetchDetailsData() {
      console.log('spuId', this.spuId, 'shopId', this.shopId);
      sendRequest({
        path: 'product/detail',
        data: {
          Seq: this.seq,
          Limit: 8,
          Source: 'Detail',
          SpuID: this.spuId,
          ShopID: this.shopId,
          ABTestMark: '',
          ActivityType: 0,
          ChannelId: 1,
          GroupShopID: ''
        },
        success: (res) => {
          let processedRes = this.processDetailsResponse(res.body);
          console.log('processed details response ', processedRes);
          setData({
            details: processedRes
          });
        },
        fail: (err) => {
          console.log('request feeds failed', err);
        }
      });
    }

    processDetailsResponse(resp) {
      // callNative("product_details", "initProduct", JSON.stringify(resp), null)
      let items = {};
      let topImages = [];

      if (resp.ProductInfo == null || resp.ProductInfo.SpuInfo == null) {
        log("mapImagesAndPrice null")
        log(resp.ProductInfo)
      }

      resp.ProductInfo.SpuInfo.ImgUrl.forEach((item, index) => {
        topImages.push({
          pic: item//,
          //event: this.getCommandByImageUrl(resp.ProductInfo.SpuInfo.ImgUrl, index)
        });
      });
      items.topImages = topImages;
      return items;
    }

    fetchData() {
      sendRequest({
        path: 'recommend/feedsproductdetail',
        data: {
          Seq: this.seq,
          Limit: 8,
          Source: '3',
          SpuID: this.spuId,
          ShopID: this.shopId
        },
        success: (res) => {
          let processedRes = this.processResponse(res.body);
          this.items = this.items.concat(processedRes);
          console.log('processed items length ' + this.items.length);
          setData({
            items: this.items
          });
        },
        fail: (err) => {
          console.log('request feeds failed', err);
        }
      });
    }

    processResponse(resp) {
      let items = [];
      if (resp.ItemList) {
        resp.ItemList.forEach(item => {
          let spu = item.SpuInfo;
          if (spu) {
            var titlePrefixLabels = '';
            var labels = [];
            var showWaistInfo = false;
            var showEasyBuy = false;
            var showFruitGuarantee = false;
            var showCoupon = false;
            var showAllowance = false;
            var coupon = 0;
            var allowance = 0;
            if (spu.hasOwnProperty('Tags')) {
              if (spu.Tags.hasOwnProperty('3')) {
                showEasyBuy = true;
                showWaistInfo = true;
              }
              if (spu.Tags.hasOwnProperty('20')) {
                showFruitGuarantee = true;
                showWaistInfo = true;
              }
              if (spu.Tags.hasOwnProperty('4')) {
                titlePrefixLabels += '[nb-span]';
                labels.push('[label("品牌"), textSize(11), textColor(0xFFFFFF), backgroundColor(0x000000), radius(2), paddingTop(1), marginRight(2)]');
              }
              if (spu.Tags.hasOwnProperty('5')) {
                titlePrefixLabels += '[nb-span]';
                labels.push('[label("全网低价"), textSize(11), textColor(0xFFFFFF), backgroundColor(0xED2F49), radius(2), paddingTop(1), marginRight(2)]');
              }
            }
            //                    if (spu.hasOwnProperty('WaistInfo')) {
            //                        if (spu.WaistInfo.hasOwnProperty('Coupon') && spu.WaistInfo.Coupon.hasOwnProperty('Name')) {
            //                            showCoupon = true;
            //                            coupon = spu.WaistInfo.Coupon.Name;
            //                            showWaistInfo = true;
            //                        }
            //                        if (spu.WaistInfo.hasOwnProperty('Allowance') && spu.WaistInfo.Allowance.hasOwnProperty('Name')) {
            //                            showAllowance = true;
            //                            allowance = spu.WaistInfo.Allowance.Name;
            //                            showWaistInfo = true;
            //                        }
            //                    }
            var title = spu.Title;
            var labelStyles = '';
            if (titlePrefixLabels.length > 0) {
              // title = titlePrefixLabels + title;
              labelStyles = '[';
              labels.forEach((label, index) => {
                labelStyles += label;
                if (index < labels.length) {
                  labelStyles += ',';
                }
              });
              labelStyles += ']';
            }
            let showSpuDesc = spu.hasOwnProperty('SpuDescription');
            let item = {
              id: spu.SpuID,
              title,
              labelStyles,
              image: CommonBusinessScripts.spuImage(spu),
              minPrice: CommonBusinessScripts.formatPrice(spu.MinPrice),
              price: CommonBusinessScripts.formatPrice(spu.MinPrice),
              marketPrice: CommonBusinessScripts.formatPrice(spu.MarketPrice),
              shopId: spu.ShopID,
              showSpuDesc,
              showEasyBuy,
              showCoupon,
              showAllowance,
              coupon,
              allowance,
              showWaistInfo,
              showFruitGuarantee,
              spuDesc: spu.SpuDescription
            };
            if (item.hasOwnProperty('ItemHeadInfo') && item.ItemHeadInfo.hasOwnProperty('Logo')) {
              item['spuLogo'] = item.ItemHeadInfo.Logo;
            }
            items.push(item);
          }
        });
      }
      return items;
    }
  }
}