export default function ({ sendRequest, setData, platform, route }) {
  return class Feeds {
    constructor({ props }) {
      this.props = props;
      this.seq = 1;
      this.items = [];
      this.Query = "";
      this.SearchType = 1;
      this.Asc = false;
      this.FilterList = [];
      this.SessionID = "04C95B2E-2F61-4FBF-B393-BE546612F92F";
      this.isEnd = false;
      console.log('searchJS search route: ' + route  +' '+ JSON.stringify(route.queryParams));
    }

    onLoad() {
        console.log('searchJS onLoad and items length is ' + this.items.length);
    }

    onInputChanged(options) {
      const { Query, SearchType, Asc, FilterList, SessionID } = options.value;
      console.log('searchJS onInputChanged:' + Query + ', ' + SearchType + ', ' + Asc + ', ' + FilterList + ', ' + SessionID)
      if (Query) {
        this.Query = Query;
      }
      if (SearchType) {
        this.SearchType = SearchType;
      }
      if (Asc !== null) {
        this.Asc = Asc;
      }
      if (FilterList) {
        this.FilterList = FilterList;
      }
      if (SessionID) {
        this.SessionID = SessionID;
      }
      this.items = [];
      this.isEnd = false;
      this.seq = 1;
      this.fetchData();
    }

    onRefresh() {
      console.log('searchJS onRefresh');
      this.seq = 1;
      this.items = [];
      setData({
        showLoading: false
      })
      this.onLoad();
    }

    onReachBottom() {
      console.log('searchJS onReachBottom');
      this.loadMore();
    }

    loadMore() {
      console.log('searchJS loadMore and isEnd is ' + this.isEnd);
      if (this.isEnd) {
        setData({
          showLoading: false
        });
      } else {
        this.seq += 1;
        setData({
          showLoading: true
        });
        this.fetchData();
      }
    }

    fetchData() {
      console.log('searchJS search goods fetchData and items length is ' + this.items.length);
      sendRequest({
        path: 'search/goods',
        data: {
          Query: this.Query,
          Seq: this.seq,
          Source: 'mainSite',
          SearchType: this.SearchType,
          Asc: this.Asc,
          FilterList: this.FilterList,
          RelatedSearchTime: 0,
          SessionID: this.SessionID
        },
        success: (res) => {
          let processedRes = this.processResponse(res.body);
          this.items = this.items.concat(processedRes);
          console.log('searchJS processed items length ' + this.items.length);
          setData({
            items: this.items
          });
        },
        fail: (err) => {
          console.log('searchJS request feeds failed', err);
        }
      });
    }

    processResponse(resp) {
      let items = [];
      if (resp.FilterList) {
        try {
          callNative('search_filter', 'handleFilterList', {"FilterList" : resp.FilterList}, (res) => {
            console.log('searchJS callNative search_filter handleFilterList', res);
          })
        } catch (e) {
          console.error('callNative search_filter failed', e);
        }
      }
      var reportData = {};
      if (resp.SpuList) {
        resp.SpuList.forEach(item => {
          let clickParamsStr = JSON.stringify({
            SpuID: Number(item.SpuInfo.SpuID),
            ShopID: Number(item.SpuInfo.ShopID)
          });

          reportData.item = JSON.stringify(item);
          reportData.searchSessionId = this.SessionID;
          var showImageWaistInfo = false;
          var tos = '';
          var showTos = false;
          var coupons = '';
          var showCoupons = false;
          var myHistory = '';
          var myHistoryIcon = '';
          var showMyHistory = false;
          var gsBehaviorDesc = '';
          var gsBehaviorImage = '';
          var showGSBehavior = false;
          var showGSBehaviorImage = false;
          var titlePrefixLabels = '';
          var labels = [];
          var showTags = false;
          if (item.hasOwnProperty('SmartUIInfo')) {
            let uiInfo = item.SmartUIInfo;
            if (uiInfo.hasOwnProperty('UIWidgetsMap')) {
              let widgetsMap = uiInfo.UIWidgetsMap;
              const tosWrap = widgetsMap.UI_WIDGET_TYPE_TOS;
              const tosInfoList = tosWrap && tosWrap.WidgetList;
              if (tosInfoList && tosInfoList.length) {
                tos = tosInfoList.map(item => item.Value).join('·');
                showTos = true;
                console.log('smart tos: ' + tos);
              }
              const couponWrap = widgetsMap.UI_WIDGET_TYPE_COUPON;
              const couponInfoList =  couponWrap && couponWrap.WidgetList;
              if (couponInfoList && couponInfoList.length) {
                coupons =  couponInfoList.map(item => item.Value).join(' ');
                showCoupons = true;
                console.log('smart gsBehavior: ' + coupons);
              }
              const historyWrap = widgetsMap.UI_WIDGET_TYPE_MY_BEHAVIOR;
              const historyInfos = historyWrap && historyWrap.WidgetList;
              if (historyInfos && historyInfos.length) {
                myHistory = historyInfos[0].Value;
                if (myHistory[0] === '买') {
                  myHistoryIcon = "https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/buy.svg";
                } else {
                  myHistoryIcon = "https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/home-page/view.svg";
                }
                showMyHistory = true;
                console.log('smart myHistory: ' + myHistory);
              }
              const gsBehaviorWrap = widgetsMap.UI_WIDGET_TYPE_SOCIAL_FRIEND_BEHAVIOR;
              const gsBehaviorInfos = gsBehaviorWrap && gsBehaviorWrap.WidgetList;
              if (gsBehaviorInfos && gsBehaviorInfos.length) {
                const desc = gsBehaviorInfos.find(item => item.ValueType === 'VALUE_TYPE_TEXT');
                gsBehaviorDesc = desc ? desc.Value : '';
                const avatar = gsBehaviorInfos.find(item => item.ValueType === 'VALUE_TYPE_URL');
                gsBehaviorImage = avatar ? avatar.Value : '';
                showGSBehavior = true;
                if (gsBehaviorImage.length > 0) {
                  showGSBehaviorImage = true;
                }
                console.log('smart gsBehavior: ' + gsBehaviorDesc + ' ' + gsBehaviorImage);
              }
              const tagWrap = widgetsMap.UI_WIDGET_TYPE_TAG;
              const tagInfos = tagWrap && tagWrap.WidgetList;
              if (tagInfos && tagInfos.length) {
                tagInfos.map((item) => {
                  let color = '0x000';
                  if (item.ID === '4') {
                    color = '0xC27E4C';
                  }
                  if (item.ID === '30') {
                    color = '0x32B255';
                  }
                  if (item.ID === '42') {
                    color = '0xED2F49';
                  }
                  titlePrefixLabels += '[nb-span]';
                  labels.push('[label("' + item.Value +'"), textSize(28), backgroundColor(0xFFFFFF), textColor(' + color +'), paddingTop(4), marginRight(4)]');
                });
                showTags = true;
                console.log('smart tags: ' + JSON.stringify(labels));
              }
            }
          }
          let spu = item.SpuInfo;
          var activityPrice = 0;
          var marketPrice = 0;
          if (spu) {
            if (spu.hasOwnProperty('MinPrice')) {
              activityPrice = spu.MinPrice;
            }
            if (spu.hasOwnProperty('minPrice')) {
              activityPrice = spu.minPrice;
            }
            if (spu.hasOwnProperty('activityPrice')) {
              activityPrice = spu.activityPrice;
              marketPrice = activityPrice;
            }
            if (spu.hasOwnProperty('MarketPrice')) {
              marketPrice = spu.MarketPrice;
            }
            if (marketPrice === 0 && spu.hasOwnProperty('MaxPrice')) {
              marketPrice = spu.MaxPrice;
            }
            if (spu.hasOwnProperty('ResponseOption') && spu.ResponseOption.hasOwnProperty('opActivityMinPrice')) {
              let option = spu.ResponseOption;
              var now = new Date().getTime();
              if (option.opActivityStartTime != null && option.opActivityEndTime != null) {
                if (option.opActivityStartTime - now <= 0 && option.opActivityEndTime - now >= 0) {
                  activityPrice = option.opActivityMinPrice;
                }
              }
            }
            var title = spu.Title;
            var labelStyles = '';
            if (titlePrefixLabels.length > 0) {
              // title = titlePrefixLabels + title;
              labelStyles = '[';
              labels.forEach((label, index) => {
                labelStyles += label;
                if (index < labels.length) {
                  labelStyles += ',';
                }
              });
              labelStyles += ']';
            }
            var saleCount = "已拼"+spu.Sales +"单"
            var sessionId = this.SessionID
            let item = {
              id: spu.SpuID,
              shopId: spu.ShopID,
              title,
              labelStyles,
              image: spu.ImgUrl,
              minPrice: CommonBusinessScripts.formatPrice(activityPrice),
              price: CommonBusinessScripts.formatPrice(activityPrice),
              marketPrice: CommonBusinessScripts.formatPrice(marketPrice),
              clickParams: clickParamsStr,
              showImageWaistInfo,
              showTos,
              tos,
              showCoupons,
              coupons,
              showMyHistory,
              myHistory,
              myHistoryIcon,
              showGSBehavior,
              showGSBehaviorImage,
              gsBehaviorDesc,
              gsBehaviorImage,
              isProductItem: true,
              isRecommendItem: false,
              saleCount,
              sessionId,
              reportData
            };
            items.push(item);
          }
        });
      } else {
        this.isEnd = true;
      }
      if (resp.RelatedSearchList) {
        resp.RelatedSearchList.forEach(item => {
          let recommendItem = {
            isRecommendItem: true,
            isProductItem: false,
            relatedSearchWords: item.TermList
          };
          let index = item.Index - 1
          if (index >= items.size) {
            index = items.size;
          }
          console.log('RelatedSearchList index : ' + index)
          items.splice(index, 0, recommendItem);
        });
      }
      return items;
    }

    onRelatedSearchClicked(options) {
      console.log('onRelatedSearchClicked options is ' + JSON.stringify(options));
      if (options.searchWord) {
        try {
          callNative('search_filter', 'onRelatedSearchClicked', {"searchWord" : options.searchWord}, (res) => {
            console.log('searchJS callNative search_filter onRelatedSearchClicked', res);
          })
        } catch (e) {
          console.error('callNative search_filter failed', e);
        }
      }
    }
  }


}