export default function ({sendRequest, setData, platform, route}) {
    return class Feeds {
        constructor({props}) {
            console.log('route: ' + JSON.stringify(route.queryParams));
            const {shopId} = route.queryParams;
            if (shopId) {
                this.shopId = Number(shopId)
            }
            this.items = [];
        }

        onLoad() {
            this.fetchData();
        }

        onRefresh() {
            this.item = {};
            setData({
                showLoading: false
            })
            this.onLoad();
        }

        onReachBottom() {
            this.loadMore();
        }

        loadMore() {
            setData({
                showLoading: true
            });
            this.fetchData();
        }

        fetchData() {
            let posInfo = {
                ShopID: this.shopId,
                PositionID: 7
            }
            let postInfo2 = {ShopID: this.shopId, PositionID: 6}
            let postInfos = []
            postInfos.push(posInfo)
            postInfos.push(postInfo2)
            sendRequest({
                path: 'ops/rom',
                data: {
                    Source: "",
                    User: [],
                    PosInfo: postInfos
                },
                success: (res) => {
                    this.items = this.processResponse(res.body);
                    for (let i = 0; i < this.items.length; i++) {
                      this.items[i].marginLeft = (i == 0) ? 12 : 6;
                      this.items[i].marginRight = (i == this.items.length - 1) ? 12 : 6;
                    }
                    setData({
                        items: this.items,
                        visible: this.items.length !== 0
                    });
                },
                fail: (err) => {
                    console.log('request feeds failed', err);
                }
            });
        }

        processResponse(resp) {
            let items = [];
            if (resp == null || resp.ContentItems == null ||
                resp.ContentItems.length === 0 || resp.ContentItems["6"] == null ||
                resp.ContentItems["6"].PromotionInfo == null || resp.ContentItems["6"].PromotionInfo.length === 0) {
                return items
            }

            resp.ContentItems["6"].PromotionInfo.forEach(it => {
                let MinTriggerAmount = ""
                if(it.MinTriggerAmount > 0){
                    MinTriggerAmount = "满" + CommonBusinessScripts.formatPrice(it.MinTriggerAmount) + "可用"
                } else {
                    MinTriggerAmount = "无门槛"
                }
                let item = {
                    MinTriggerAmount: MinTriggerAmount,
                    PromotionAmount: CommonBusinessScripts.formatPrice(it.PromotionAmount),
                    Signature: it.RuleToken,
                    showText: it.Status === 1,
                    showImage: it.Status !== 1,
                    showMinTriggerAmount: true,
                    showNOMinTriggerAmount : false,
                    status: it.Status,
                    disableFlag: 'https://ops-1300522992.cos.ap-guangzhou.myqcloud.com/doc/YZ/images/main/disable-flag.png'
                }
                console.log('coupon-item', item);
                console.log('coupon-item', it);
                items.push(item)
            })
            console.log('resp :' + JSON.stringify(items));
            return items;
        }

        grabpromotion(index) {
            //promotion/grabpromotion
            //Info: ""
            //   Signature: "1d14865c50aa6fbd21ffbac20f58c033e5bcf2ced608470bfed1f93fb9389f32886c269c71f2f9efc3b493c96e1d61a9a99d6b1f0431e7ece543c29d2bb490d68da79d78a468ead55e4f8a2028559b5e76dd481fb5861af0ced92bca4155778d29e5c4153de94ef9715309b5f5851e82a4a1deef8ee3982c280c5fe5a89d761a"
            // TradeOrderID: "
            console.log('contactClick click：' + JSON.stringify(index));
            let item = this.items[index]
            sendRequest({
                path: 'promotion/grabpromotion',
                data: {
                    Info: "",
                    Signature: item.Signature,
                    PosInfo: ""
                },
                success: (res) => {
                    item.status = 2
                    item.showText = false
                    item.showImage = true
                    console.log('processed ' + this.item);
                    setData({
                        items: this.items,
                        visible: this.items.length !== 0
                    });
                },
                fail: (err) => {
                    console.log('request feeds failed', err);
                }
            });
        }
    }
}