export default function ({sendRequest, setData, platform, route}) {
    return class Feeds {
        constructor({props}) {
            console.log('route: ' + JSON.stringify(route.queryParams));
            const {shopId} = route.queryParams;
            if (shopId) {
                this.shopId = Number(shopId)
            }
            this.seq = 0;
            this.items = [];
            this.offset = 0;
        }

        onLoad() {
            this.fetchData();
        }

        onRefresh() {
            this.seq = 0;
            this.offset = 0;
            this.items = [];
            setData({
                showLoading: false
            })
            this.onLoad();
        }

        onReachBottom() {
            this.loadMore();
        }

        loadMore() {
            this.offset += 8;
            setData({
                showLoading: true
            });
            this.fetchData();
        }

        fetchData() {
            //{ShopID: 20519, ShopPageModule: 1, offset: 6, Limit: 6}
            sendRequest({
                path: 'shop/shoppage',
                data: {
                    offset: this.offset,
                    Limit: 8,
                    ShopPageModule: 1,
                    ShopID: this.shopId
                },
                success: (res) => {
                    let processedRes = this.processResponse(res.body);
                    this.items = this.items.concat(processedRes);
                    console.log('processed items length ' + this.items.length);
                    setData({
                        items: this.items
                    });
                },
                fail: (err) => {
                    console.log('request feeds failed', err);
                }
            });
        }

        processResponse(resp) {
            let items = [];
            resp.ShopSpuList.forEach(spu => {
                var title = spu.Title;
                var labelStyles = '';
                var showSpuDesc = false;
                var showEasyBuy = false;
                var showCoupon = false;
                var showAllowance = false;
                var coupon = 0;
                var allowance = 0;
                var showWaistInfo = false;
                var showFruitGuarantee = false;
                let item = {
                    id: spu.SpuID,
                    title,
                    labelStyles,
                    image: spu.ImgUrl[0],
                    minPrice: CommonBusinessScripts.formatPrice(spu.MinPrice),
                    price: CommonBusinessScripts.formatPrice(spu.MaxPrice),
                    marketPrice: CommonBusinessScripts.formatPrice(spu.MinPrice),
                    shopId: this.shopId,
                    showSpuDesc,
                    showEasyBuy,
                    showCoupon:true,
                    showAllowance:"https://mvp-1300522992.image.myqcloud.com//misc/0_1614782761737376001.png",
                    coupon,
                    allowance,
                    showWaistInfo,
                    showImageWaistInfo:true,
                    showFruitGuarantee,
                    spuDesc: spu.Title
                }
                console.log('item: ' + JSON.stringify(item));
                items.push(item)
            })
            return items;
        }
    }
}