export default function ({sendRequest, setData, platform, route}) {
    return class Feeds {
        constructor({props}) {
            console.log('route: ' + JSON.stringify(route.queryParams));
            const {shopId} = route.queryParams;
            if (shopId) {
                this.shopId = Number(shopId)
            }
            this.seq = 0;
            this.item = {};
        }

        onLoad() {
            this.fetchData();
        }

        onRefresh() {
            this.seq = 0;
            this.item = {};
            setData({
                showLoading: false
            })
            this.onLoad();
        }

        onReachBottom() {
            this.loadMore();
        }

        loadMore() {
            this.seq += 1;
            setData({
                showLoading: true
            });
            this.fetchData();
        }

//{ShopID: 20519, ShopPageModule: 0, offset: 0, Limit: 6}

        fetchData() {
            let item = {
                storeIcon: "",
                storeName: "",
                saleCount: "",
                shopId: this.shopId
            };
            setData({
                item: item
            });
            sendRequest({
                path: 'shop/shoppage',
                data: {
                    Seq: this.seq,
                    ShopID: this.shopId,
                    ShopPageModule: 0
                    //Source: '2'
                },
                success: (res) => {
                    this.item = this.processResponse(res.body);
                    console.log('processed ' + this.item);
                    setData({
                        item: this.item
                    });
                },
                fail: (err) => {
                    console.log('request feeds failed', err);
                }
            });
        }

        processResponse(resp) {
            let shopInfo = resp.ShopInfo
            let saleCount = ""
            let count = 0
            if(shopInfo.ShopSale){
                count = shopInfo.ShopSale
            }
            if (count >= 100000000) {
                saleCount = "已拼" + (count / 100000000).toFixed(2) + "亿+件";
            } else if (count >= 10000) {
                saleCount = "已拼" + (count / 10000).toFixed(2) + "万+件";
            } else {
                saleCount = "已拼" + count + "件";
            }
            let shopLogo = ""
            let shopName = ""
            let shopSpuCount = 0
            if(shopInfo.ShopSpuCount){
                shopSpuCount = shopInfo.ShopSpuCount
            }
            let item = {
                storeIcon: shopInfo.ShopLogo,
                storeName: shopInfo.ShopName,
                goodsCount: shopSpuCount,
                saleCount: saleCount,
                shopId: this.shopId
            };
            this.storeIcon = shopInfo.ShopLogo
            this.storeName = shopInfo.ShopName
            console.log('resp: ' + JSON.stringify(item));
            return item;
        }

        contactClick() {
            try {
                callNative('shop_detail_filter', 'contact',
                    {"storeIcon": this.storeIcon, "storeName": this.storeName, "shopId": this.shopId},
                    (res) => {
                        console.log('callNative search_filter handleFilterList', res)
                    })
            } catch (e) {
                console.error('callNative search_filter failed', e)
            }
            console.log('contactClick click');
        }
    }
}