// Core - Bridging

const _nb_instance_pool = {};

const _nb_callback = {
    callbackID: 1,
    callbacks: {}
};

function callNative(module, method, params, callback) {
    let callbackId = _nb_callback.callbackID + '';
    let call = { module, method, callbackId, params };
    if (callback) {
        _nb_callback.callbacks[callbackId] = callback;
        _nb_callback.callbackID = _nb_callback.callbackID + 1;
    }
    nb_js_bridge_callNative(JSON.stringify(call));
}

/**
 *  JS Bridge callback by nb_js_bridge_callback
 *
 *  @callbackId passby
 *  @success  jsapi run result
 *  @params jsapi params
 */
function nb_js_bridge_callback(callbackId, success, params) {
    if (!callbackId) {
        return;
    }
    let callback = _nb_callback.callbacks[callbackId];
    if (callback) {
        // log('nb_js_bridge_callback find callback:' + callbackId);
        let jsonParams = {};
        if (params) {
            // need to decode url params to json string
            let decoded = decodeURIComponent(params);
            // parse json string to object
            let jsonData = null;
            try {
                jsonParams = JSON.parse(decoded);
            } catch (e) {
                log('nb_js_bridge_callback parse json exception: ' + result);
            }
        }
        callback(jsonParams)
    } else {
        log('nb_js_bridge_callback not find callback: ' + callbackId);
    }
    // delete callback
    delete _nb_callback.callbacks[callbackId];
}

/**
*	调用jsapi格式: nb_js_bridge_callNative('json字符串')， json包括
*	@module： 模块名
*	@method： 方法名
*	@callbackId： 回调ID，执行成功后，会调用nb_js_bridge_callback方法，并透传回来callbackId
*	@params 方法参数
*	jsapi参见： https://iwiki.woa.com/pages/viewpage.action?pageId=302119223
*
*	示例：nb_js_bridge_callNative('{"module": "interaction", "method":"showToast", "callbackId":"12345","params": {"":1, "b":2}}');
*/

// Support console.log

const LOG_LEVEL = {
    Info: 0,
    Debug: 1,
    Warning: 2,
    Error: 3,
};

const console = {
    log: function (...params) {
        log(params.map((param) => JSON.stringify(param)).join(' '));
    },
    error: function(...params) {
        log(params.map((param) => JSON.stringify(param)).join(' '), LOG_LEVEL.Error);
    }
}

function log(log, level) {
    if (!log) {
        return
    }
    let params = {
        level: level || LOG_LEVEL.Debug,
        tag: "JSAPI",
        log: log,
    };
    callNative("log", "log", params)
}

// window.setTimeout
function setTimeout(fn, delay) {
    fn();
}

function showToast(msg) {
    let callback = (params) => {
        log('showToast callback code:' + params.code + ' msg: ' + params.msg);
    };
    callNative("interaction", "showToast", `{"title":"${msg}"}`, callback);
}

// Global scroll method for an AresView
function scrollBy(x, y) {
    callNative('ares', 'scrollBy', { "x": x, "y": y }, null)
}

function openRouterUrl(url) {
    if(!url) {
        return;
    }

    let json = '{"url":"' + url + '"}';
    callNative("router", "navigateTo", json, (jsonData) => {
        log('openRouterUrl code: ' + jsonData.code + " msg: " + jsonData.msg);
    })
}

class CommonBusinessScripts {
    static onOpenProductItem(data) {
        let params = {
            url: 'yz://product-detail',
            data: data
        };
        callNative("router", "navigateTo", JSON.stringify(params), null)
    }

    static formatPrice(priceCent) {
        if (priceCent % 100 == 0) {
            return (priceCent / 100).toFixed(0);
        } else if (priceCent % 10 == 0) {
            return (priceCent / 100).toFixed(1);
        }
        return (priceCent / 100).toFixed(2);
    }

    static spuImage(spu) {
        if (spu) {
            let image = spu.imageUrl || spu.ImgUrl;
            if (typeof image === 'object' && image.length && image.length > 0) {
                return image[0];
            }
        }
        return image || '';
    }

    static getPriceDecimal(price) {
        if (price % 100 === 0) {
            return '';
        }
        return ((price % 100) / 100).toFixed(2).toString().substring(1);
    }
}

TAGS = {
    EASE_BUY: 3, // 放心购
    BRAND: 4, // 品牌， 商品标题头部
    ALL_LOW_PRICE: 5, // 全网低价
    FREE_RETURN: 6, // 退货包邮 商品标题尾部
    PAY_ONE_FAKE: 7, // 假一赔十
    LABEL_8: 8,
    LABEL_12: 12,
    PRE_SALE: 18, // 预售,
    BAD_FRUIT: 20, // 坏果包赔
    BAD_PRODUCT: 27, // 坏品包赔
    MOTHER_EASE: 28, // 妈妈放心
    DAMAGED: 29, // 破损包赔
    LABEL_30: 30, // 助农直降
    COUPON: 'coupon-tag',
    ALLOWANCE: 'allowance-tag',
};

// bgColor_textColor
TAG_COLORS = {
    GREEN_GREEN: 0,
    GREEN_WHITE: 1,
    RED_WHITE: 2,
    BLACK_WHITE: 3,
};

TagConfigs = {};
TagConfigs[TAGS.LABEL_30] = TAG_COLORS.GREEN_WHITE;

TagConfigs[TAGS.PRE_SALE] = TAG_COLORS.RED_WHITE;
TagConfigs[TAGS.LABEL_12] = TAG_COLORS.RED_WHITE;
TagConfigs[TAGS.COUPON] = TAG_COLORS.RED_WHITE;
TagConfigs[TAGS.ALLOWANCE] = TAG_COLORS.RED_WHITE;
TagConfigs[TAGS.ALL_LOW_PRICE] = TAG_COLORS.RED_WHITE;
TagConfigs[TAGS.MOTHER_EASE] = TAG_COLORS.RED_WHITE;

TagConfigs[TAGS.BRAND] = TAG_COLORS.BLACK_WHITE;

TagConfigs[TAGS.BAD_FRUIT] = TAG_COLORS.GREEN_GREEN;
TagConfigs[TAGS.FREE_RETURN] = TAG_COLORS.GREEN_GREEN;
TagConfigs[TAGS.PAY_ONE_FAKE] = TAG_COLORS.GREEN_GREEN;
TagConfigs[TAGS.LABEL_8] = TAG_COLORS.GREEN_GREEN;

class Tags {
    static getTagsPlaceHolder(tags) {
        let count = tags.length
        let placeHolder = '';
        while (count--) {
            placeHolder += '[nb-span]';
        }
        return placeHolder;
    }

    static hasTag(tags, tagKey) {
        return tags && tags[tagKey] && tags[tagKey].TagName && tags[tagKey].TagName.length > 0;
    }

    static getTags(tags, showTags) {
        let tagList = [];
        for (const tagKey of showTags) {
            if (this.hasTag(tags, tagKey)) {
                tagList.push(this.getTagAttrs(tags[tagKey].TagName, TagConfigs[tagKey]));
            }
        }

        return tagList;
    }

    static getTagAttrs(tag, tagColor) {
        let textColor;
        let bgColor;
        switch (tagColor) {
            case TAG_COLORS.GREEN_GREEN:
                bgColor = 'backgroundColor(0x1902994C)'
                textColor = 'textColor(0x02994C)';
                break;
            case TAG_COLORS.RED_WHITE:
                bgColor = 'backgroundColor(0xED2F49)'
                textColor = 'textColor(0xFFFFFF)';
                break;
            case TAG_COLORS.GREEN_WHITE:
                bgColor = 'backgroundColor(0x32B255)'
                textColor = 'textColor(0xFFFFFF)';
                break;
            case TAG_COLORS.BLACK_WHITE:
                bgColor = 'backgroundColor(0x000000)'
                textColor = 'textColor(0xFFFFFF)';
                break;
        }

        let tagAttrs = [];
        tagAttrs.push('label("' + tag.toString().slice(0, 6) + '")');
        tagAttrs.push('textSize(12)');
        tagAttrs.push(textColor);
        tagAttrs.push(bgColor);
        tagAttrs.push('radius(2)');
        tagAttrs.push('paddingTop(1)');
        tagAttrs.push('marginRight(2)');

        return tagAttrs;
    }
}